@@ -13,8 +13,6 @@ const julia07 = VERSION > v"0.6.5"
 
 if julia07
     using Pkg
-else
-    macro pkg_str(x) begin nothing end end
 end
 
 function installed(name)
